@@ -10,14 +10,15 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import UpdateCommand from '@oclif/plugin-update/lib/commands/update'
 import { ux } from '@oclif/core'
 import * as notifier from 'node-notifier'
-import {newError} from './utls'
+import {getProjectName, newError} from './utls'
 import {CheCtlContext, CliContext} from '../context'
 import * as fs from 'node:fs'
-import {CheCtlVersion} from './chectl-version'
 import {EclipseChe} from '../tasks/installers/eclipse-che/eclipse-che'
+import * as execa from 'execa'
+import * as path from 'node:path'
+import {CheCtlVersion} from './chectl-version'
 
 /**
  * Returns command success message with execution time.
@@ -68,8 +69,8 @@ export async function askForChectlUpdateIfNeeded(): Promise<void> {
   if (await CheCtlVersion.isCheCtlUpdateAvailable(ctx[CliContext.CLI_CACHE_DIR])) {
     ux.info(`A more recent version of dsc is available. To deploy the latest version of ${EclipseChe.PRODUCT_NAME}, update the dsc tool first.`)
     if (await ux.confirm('Do you want to update dsc now? [y/n]')) {
-      // Update dsc
-      await UpdateCommand.run([])
+      const bin = path.join(__dirname, '..', '..', 'bin', getProjectName())
+      await execa(bin, ['update'], {stdout: 'inherit', stderr: 'inherit', timeout: 60_000})
       ux.exit(0)
     }
   }
